# grammar-gpt





# API
```Python
>>> from grammar_gpt import GrammarHelper
>>> gh = GrammarHelper()
>>> gh.polish('I am not like dance')
'I do not like to dance.'


>>> gh.translate('How are you doing')
'你好吗？'
>>> gh.translate('whats up')
'最近怎么样？'

```
